.. django-rql documentation master file, created by
   sphinx-quickstart on Fri Aug  7 10:27:30 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-rql's documentation!
======================================

`django-rql` is an Django application, that implements RQL filter backend for your web application.


RQL
---

RQL (Resource query language) is designed for modern application development. It is built for the web, ready for NoSQL, and highly extensible with simple syntax.
This is a query language fast and convenient database interaction. RQL was designed for use in URLs to request object-style data structures.


`RQL Reference <https://connect.cloudblue.com/community/api/rql/>`_

`RQL for Web <https://www.sitepen.com/blog/resource-query-language-a-query-language-for-the-web-nosql/>`_



.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   user_guide
   select
   reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
